Citing the package
==================

To cite or reference :mod:`flory` in other work, please refer to the `publication in
the Journal of Open Source Software <https://doi.org/10.21105/joss.07388>`_.
Here are the respective bibliographic records in Bibtex format:

.. code-block:: bibtex

   @article{florypackage,
      title = {{flory}: A {Python} package for finding coexisting phases in multicomponent mixtures},
      author = {Qiang, Yicheng and Zwicker, David},
      year = {2025},
      month = mar,
      journal = {Journal of Open Source Software},
      volume = {10},
      number = {107},
      pages = {7388},
      issn = {2475-9066},
      doi = {10.21105/joss.07388}
   }


and in RIS format:

.. code-block:: text

   TY  - JOUR
   TI  - flory: A Python package for finding coexisting phases in multicomponent mixtures
   AU  - Qiang, Yicheng
   AU  - Zwicker, David
   T2  - Journal of Open Source Software
   DA  - 2025/03/11/
   PY  - 2025
   DO  - 10.21105/joss.07388
   VL  - 10
   IS  - 107
   SP  - 7388
   J2  - JOSS
   SN  - 2475-9066
   ST  - flory
   UR  - https://joss.theoj.org/papers/10.21105/joss.07388


